"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ContentSearchClientService = void 0;
const tslib_1 = require("tslib");
const debounce_1 = tslib_1.__importDefault(require("lodash/debounce"));
const di_1 = require("@opensumi/di");
const ide_components_1 = require("@opensumi/ide-components");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const core_preferences_1 = require("@opensumi/ide-core-browser/lib/core-preferences");
const storage_service_1 = require("@opensumi/ide-core-browser/lib/services/storage-service");
const ide_core_common_1 = require("@opensumi/ide-core-common");
const ide_editor_1 = require("@opensumi/ide-editor");
const browser_1 = require("@opensumi/ide-editor/lib/browser");
const monaco = tslib_1.__importStar(require("@opensumi/ide-monaco"));
const ide_overlay_1 = require("@opensumi/ide-overlay");
const ide_workspace_1 = require("@opensumi/ide-workspace");
const ide_workspace_edit_1 = require("@opensumi/ide-workspace-edit");
const common_1 = require("../common");
const replace_1 = require("./replace");
const search_history_1 = require("./search-history");
const search_preferences_1 = require("./search-preferences");
const search_result_collection_1 = require("./search-result-collection");
function splitOnComma(patterns) {
    return patterns.length > 0 ? patterns.split(',').map((s) => s.trim()) : [];
}
/**
 * 用于文件内容搜索
 */
let ContentSearchClientService = class ContentSearchClientService extends ide_core_common_1.Disposable {
    get onDidChange() {
        return this.onDidChangeEmitter.event;
    }
    get onDidTitleChange() {
        return this.onDidTitleChangeEmitter.event;
    }
    get onDidUIStateChange() {
        return this.onDidUIStateChangeEmitter.event;
    }
    get onDidSearchStateChange() {
        return this.onDidSearchStateChangeEmitter.event;
    }
    constructor() {
        super();
        this.onDidChangeEmitter = new ide_core_browser_1.Emitter();
        this.onDidTitleChangeEmitter = new ide_core_browser_1.Emitter();
        this.onDidUIStateChangeEmitter = new ide_core_browser_1.Emitter();
        this.onDidSearchStateChangeEmitter = new ide_core_browser_1.Emitter();
        this.UIState = {
            isToggleOpen: true,
            isDetailOpen: false,
            // Search Options
            isMatchCase: false,
            isWholeWord: false,
            isUseRegexp: false,
            isIncludeIgnored: false,
            isOnlyOpenEditors: false,
        };
        this.searchResults = new Map();
        this.searchError = '';
        this.resultTotal = { resultNum: 0, fileNum: 0 };
        this.isReplacing = false;
        this.isSearching = false;
        this.isShowValidateMessage = true;
        this.replaceValue = '';
        this.searchValue = '';
        this.includeValue = '';
        this.excludeValue = '';
        this._docModelSearchedList = [];
        this._currentSearchId = -1;
        this.searchResultCollection = new search_result_collection_1.SearchResultCollection();
        this.reporter = null;
        this.searchId = new Date().getTime();
        // #region 操作对当前打开的文档的搜索内容的 selection
        this.EMPTY_SELECTION = new monaco.Range(0, 0, 0, 0);
        this.onSearchInputChange = (text) => {
            this.searchValue = text;
            this.isShowValidateMessage = false;
            this.searchOnTyping();
        };
        this.onReplaceInputChange = (text) => {
            this.replaceValue = text;
        };
        this.onSearchExcludeChange = (text) => {
            this.excludeValue = text;
            this.searchOnTyping();
        };
        this.onSearchIncludeChange = (text) => {
            this.includeValue = text;
            this.searchOnTyping();
        };
        this.searchEditorSelection = () => {
            const currentEditor = this.workbenchEditorService.currentOrPreviousFocusedEditor;
            if (currentEditor) {
                const selections = currentEditor.getSelections();
                if (selections && selections.length > 0 && currentEditor.currentDocumentModel) {
                    const { selectionStartLineNumber, selectionStartColumn, positionLineNumber, positionColumn } = selections[0];
                    const selectionText = currentEditor.currentDocumentModel.getText(new monaco.Range(selectionStartLineNumber, selectionStartColumn, positionLineNumber, positionColumn));
                    const searchText = ide_core_browser_1.strings.trim(selectionText) === '' ? this.searchValue : selectionText;
                    this.searchValue = searchText;
                }
            }
        };
        this.shouldSearch = (uiState) => ['isWholeWord', 'isMatchCase', 'isUseRegexp', 'isIncludeIgnored', 'isOnlyOpenEditors'].some((v) => uiState[v] !== undefined && uiState[v] !== this.UIState[v]);
        this.updateUIState = (obj) => {
            const newUIState = Object.assign({}, this.UIState, obj);
            if (this.shouldSearch(obj)) {
                this.search(newUIState);
            }
            this.UIState = newUIState;
            this.onDidUIStateChangeEmitter.fire(newUIState);
            this.browserStorageService.setData('search.UIState', newUIState);
        };
        this.replaceAll = () => {
            if (this.isReplacing) {
                return;
            }
            this.isReplacing = true;
            (0, replace_1.replaceAll)(this.documentModelManager, this.workspaceEditService, this.searchResults, this.replaceValue, this.searchValue, this.UIState.isUseRegexp, this.dialogService, this.messageService, this.resultTotal).then((isDone) => {
                this.isReplacing = false;
                if (!isDone) {
                    return;
                }
                this.search();
            });
        };
        this.setDefaultIncludeValue();
        this.recoverUIState();
        this.searchOnType = this.searchPreferences["search.searchOnType" /* SearchSettingId.SearchOnType */] || true;
        const timeout = this.searchPreferences["search.searchOnTypeDebouncePeriod" /* SearchSettingId.SearchOnTypeDebouncePeriod */] || 300;
        this.searchDebounce = (0, debounce_1.default)(() => {
            this.search();
        }, timeout, {
            trailing: true,
            maxWait: timeout * 5,
        });
    }
    searchOnTyping() {
        if (this.searchOnType) {
            this.searchDebounce();
        }
    }
    async search(insertUIState) {
        const value = this.searchValue;
        this.cleanSearchResults();
        if (!value) {
            this.onDidChangeEmitter.fire();
            return;
        }
        if (this.searchCancelToken && !this.searchCancelToken.token.isCancellationRequested) {
            this.searchCancelToken.cancel();
        }
        this.searchCancelToken = new ide_core_common_1.CancellationTokenSource();
        const state = insertUIState || this.UIState;
        await this.doSearch(value, state, this.searchCancelToken.token);
    }
    async doSearch(value, state, token) {
        var _a, _b, _c;
        const searchOptions = {
            maxResults: 2000,
            matchCase: state.isMatchCase,
            matchWholeWord: state.isWholeWord,
            useRegExp: state.isUseRegexp,
            includeIgnored: state.isIncludeIgnored,
            include: splitOnComma(this.includeValue || ''),
            exclude: splitOnComma(this.excludeValue || ''),
        };
        searchOptions.exclude = this.getExcludeWithSetting(searchOptions, state);
        // 记录搜索历史
        this.searchHistory.setSearchHistory(value);
        this.isShowValidateMessage = true;
        // Stop old search
        this.isSearching = true;
        if (this._currentSearchId > -1) {
            this.contentSearchServer.cancel(this._currentSearchId);
            this._currentSearchId = this._currentSearchId + 1;
            this.reporter = null;
        }
        const rootDirSet = new Set();
        this.workspaceService.tryGetRoots().forEach((stat) => {
            const uri = new ide_core_browser_1.URI(stat.uri);
            if (uri.scheme !== ide_core_browser_1.Schemes.file) {
                return;
            }
            rootDirSet.add(uri.toString());
        });
        // 由于查询的限制，暂时只支持单一 workspace 的编码参数
        searchOptions.encoding = this.preferenceService.get('files.encoding', undefined, (_a = rootDirSet.values().next()) === null || _a === void 0 ? void 0 : _a.value);
        // FIXME: 当前无法在不同根目录内根据各自 include 搜索，因此如果多 workspaceFolders，此处返回的结果仅为一部分
        // 同时 searchId 设计原因只能针对单服务，多个 search 服务无法对同一个 searchId 返回结果
        // 长期看需要改造，以支持 registerFileSearchProvider
        if (state.isOnlyOpenEditors) {
            rootDirSet.clear();
            const openResources = ide_core_browser_1.arrays.coalesce(ide_core_browser_1.arrays.flatten(this.workbenchEditorService.editorGroups.map((group) => group.resources)));
            const includeMatcherList = ((_b = searchOptions.include) === null || _b === void 0 ? void 0 : _b.map((str) => (0, ide_core_browser_1.parseGlob)((0, common_1.anchorGlob)(str)))) || [];
            const excludeMatcherList = ((_c = searchOptions.exclude) === null || _c === void 0 ? void 0 : _c.map((str) => (0, ide_core_browser_1.parseGlob)((0, common_1.anchorGlob)(str)))) || [];
            const openResourcesInFilter = openResources.filter((resource) => {
                const fsPath = resource.uri.path.toString();
                if (excludeMatcherList.length > 0 && excludeMatcherList.some((matcher) => matcher(fsPath))) {
                    return false;
                }
                if (includeMatcherList.length > 0 && !includeMatcherList.some((matcher) => matcher(fsPath))) {
                    return false;
                }
                return true;
            });
            const include = [];
            const isAbsolutePath = (resource) => !!resource.codeUri.path && resource.codeUri.path[0] === '/';
            openResourcesInFilter.forEach(({ uri }) => {
                var _a;
                if (uri.scheme === ide_core_browser_1.Schemes.walkThrough) {
                    return;
                }
                if (isAbsolutePath(uri)) {
                    const searchRoot = (_a = this.workspaceService.getWorkspaceRootUri(uri)) !== null && _a !== void 0 ? _a : uri.withPath(uri.path.dir);
                    const relPath = searchRoot.path.relative(uri.path);
                    rootDirSet.add(searchRoot.toString());
                    if (relPath) {
                        include.push(`./${relPath.toString()}`);
                    }
                }
                else if (uri.codeUri.fsPath) {
                    include.push(uri.codeUri.fsPath);
                }
            });
            searchOptions.include = include;
            searchOptions.exclude = include.length > 0 ? undefined : ['**/*'];
        }
        const rootDirs = Array.from(rootDirSet);
        // 从 doc model 中搜索
        const searchFromDocModelInfo = await this.searchAllFromDocModel({
            searchValue: value,
            searchOptions,
            documentModelManager: this.documentModelManager,
            rootDirs,
        });
        if (token.isCancellationRequested) {
            this.isSearching = false;
            return;
        }
        this._currentSearchId = this.searchId++;
        // 从服务端搜索
        this.reporter = { timer: this.reporterService.time(ide_core_common_1.REPORT_NAME.SEARCH_MEASURE), value };
        this.contentSearchServer.search(this._currentSearchId, value, rootDirs, searchOptions).then((id) => {
            if (token.isCancellationRequested) {
                return;
            }
            this._onSearchResult({
                id,
                data: searchFromDocModelInfo.result,
                searchState: common_1.SEARCH_STATE.doing,
                docModelSearchedList: searchFromDocModelInfo.searchedList,
            });
        });
        this.watchDocModelContentChange(searchOptions, rootDirs);
    }
    setEditorSelections(editor, selections) {
        var _a;
        // 清除上一个 editor 的 selection
        (_a = this.lastEditor) === null || _a === void 0 ? void 0 : _a.setSelection(this.EMPTY_SELECTION);
        this.lastEditor = editor;
        this.lastSelection = selections;
        this.applyEditorSelections();
    }
    /**
     * 会在 tabbar 被选中时调用
     */
    applyEditorSelections() {
        if (this.lastEditor && this.lastSelection) {
            this.lastEditor.setSelection(this.lastSelection);
        }
    }
    /**
     * 会在 tabbar blur 和清除搜索结果时调用
     * @param clearEditor 是否清除上次选中的 editor（在重置搜索内容时调用）
     */
    clearEditorSelections(clearEditor = false) {
        if (this.lastEditor) {
            this.lastEditor.setSelection(this.EMPTY_SELECTION);
        }
        if (clearEditor) {
            this.lastSelection = undefined;
            this.lastEditor = undefined;
        }
    }
    // #endregion
    /**
     * 监听正在编辑文件变化，并同步结果
     * @param searchOptions
     * @param rootDirs
     */
    watchDocModelContentChange(searchOptions, rootDirs) {
        if (this.eventBusDisposer) {
            this.eventBusDisposer.dispose();
        }
        this.eventBusDisposer = this.eventBus.on(browser_1.EditorDocumentModelContentChangedEvent, (data) => {
            const event = data.payload;
            if (!this.searchResults || this.isReplacing) {
                return;
            }
            // 只搜索file协议内容
            if (event.uri.scheme !== ide_core_browser_1.Schemes.file) {
                return;
            }
            const uriString = event.uri.toString();
            const docModel = this.documentModelManager.getModelReference(event.uri);
            if (!docModel) {
                return;
            }
            const resultData = this.searchFromDocModel(searchOptions, docModel.instance, this.searchValue, rootDirs);
            const oldResults = this.searchResults.get(uriString);
            if (!oldResults) {
                // 不在结果树中，新增结果
                if (resultData.result.length > 0) {
                    this.resultTotal.fileNum++;
                    this.resultTotal.resultNum = this.resultTotal.resultNum + resultData.result.length;
                }
            }
            else if (resultData.result.length < 1) {
                // 搜索结果被删除完了，清理结果树
                this.searchResults.delete(uriString);
                this.resultTotal.fileNum = this.resultTotal.fileNum - 1;
                this.resultTotal.resultNum = this.resultTotal.resultNum - oldResults.length;
            }
            else if (resultData.result.length !== (oldResults === null || oldResults === void 0 ? void 0 : oldResults.length)) {
                // 搜索结果变多了，更新数据
                this.resultTotal.resultNum = this.resultTotal.resultNum - oldResults.length + resultData.result.length;
            }
            if (resultData.result.length > 0) {
                // 更新结果树
                this.searchResults.set(uriString, resultData.result);
            }
            this.onDidChangeEmitter.fire();
            docModel.dispose();
        });
    }
    cleanSearchResults() {
        this._docModelSearchedList = [];
        this.searchResults.clear();
        this.resultTotal = { resultNum: 0, fileNum: 0 };
        this.clearEditorSelections(true);
    }
    /**
     * 服务端发送搜索结果过来
     * @param sendClientResult
     */
    onSearchResult(sendClientResult) {
        const resultList = this.searchResultCollection.pushAndGetResultList(sendClientResult);
        resultList.forEach((result) => {
            this._onSearchResult(result);
        });
    }
    _onSearchResult(sendClientResult) {
        const { id, data, searchState, error, docModelSearchedList } = sendClientResult;
        if (!data) {
            return;
        }
        if (id > this._currentSearchId) {
            this.isSearching = true;
            this._currentSearchId = id;
            this.cleanSearchResults();
        }
        if (this._currentSearchId && this._currentSearchId > id) {
            // 若存在异步发送的上次搜索结果，丢弃上次搜索的结果
            return;
        }
        if (searchState) {
            this.searchState = searchState;
            if (searchState === common_1.SEARCH_STATE.done || searchState === common_1.SEARCH_STATE.error) {
                // 搜索结束清理ID
                this.isSearching = false;
                this._currentSearchId = -1;
            }
            if (searchState === common_1.SEARCH_STATE.done && this.reporter) {
                const { timer, value } = this.reporter;
                timer.timeEnd(value, Object.assign({}, this.resultTotal));
                this.reporter = null;
            }
        }
        if (error) {
            // 搜索出错
            this.isSearching = false;
            this.searchError = error.toString();
            this.reporter = null;
        }
        this.mergeSameUriResult(data, this.searchResults, this._docModelSearchedList, this.resultTotal);
        if (docModelSearchedList) {
            // 记录通 docModel 搜索过的文件，用于过滤服务端搜索的重复内容
            this._docModelSearchedList = docModelSearchedList;
        }
        this.onDidChangeEmitter.fire();
    }
    focus() {
        window.requestAnimationFrame(() => {
            this.onDidSearchStateChangeEmitter.fire(this.searchValue);
            this.applyEditorSelections();
        });
    }
    blur() {
        this.clearEditorSelections();
    }
    refreshIsEnable() {
        return !!(this.searchState !== common_1.SEARCH_STATE.doing && this.searchValue);
    }
    initSearchHistory() {
        return this.searchHistory.initSearchHistory();
    }
    setBackRecentSearchWord() {
        return this.searchHistory.setBackRecentSearchWord();
    }
    setRecentSearchWord() {
        return this.searchHistory.setRecentSearchWord();
    }
    clean() {
        this.searchResults.clear();
        this.resultTotal = { resultNum: 0, fileNum: 0 };
        this.searchState = common_1.SEARCH_STATE.todo;
        this.searchValue = '';
        this.replaceValue = '';
        this.excludeValue = '';
        this.includeValue = '';
        this.searchError = '';
    }
    cleanIsEnable() {
        return !!(this.searchValue ||
            this.replaceValue ||
            this.excludeValue ||
            this.includeValue ||
            this.searchError ||
            (this.searchResults && this.searchResults.size > 0));
    }
    foldIsEnable() {
        return !!(this.searchResults && this.searchResults.size > 0);
    }
    getPreferenceSearchExcludes() {
        const excludes = [];
        const fileExcludes = this.corePreferences['files.exclude'];
        const searchExcludes = this.searchPreferences['search.exclude'];
        const allExcludes = Object.assign({}, fileExcludes, searchExcludes);
        for (const key of Object.keys(allExcludes)) {
            if (allExcludes[key]) {
                excludes.push(key);
            }
        }
        return excludes;
    }
    openPreference() {
        this.commandService.executeCommand(ide_core_browser_1.COMMON_COMMANDS.OPEN_PREFERENCES.id, 'files.watcherExclude');
    }
    get searchHistory() {
        if (!this._searchHistory) {
            this._searchHistory = new search_history_1.SearchHistory(this, this.recentStorage);
        }
        return this._searchHistory;
    }
    get validateMessage() {
        if (this.resultTotal.resultNum >= common_1.DEFAULT_SEARCH_IN_WORKSPACE_LIMIT) {
            return {
                message: (0, ide_core_common_1.localize)('search.too.many.results'),
                type: ide_components_1.VALIDATE_TYPE.WARNING,
            };
        }
    }
    async recoverUIState() {
        const UIState = (await this.browserStorageService.getData('search.UIState'));
        this.updateUIState(UIState || {});
    }
    getExcludeWithSetting(searchOptions, state) {
        let result = [];
        if (searchOptions.exclude) {
            result = result.concat(searchOptions.exclude);
        }
        // 启用默认排除项
        if (!state.isIncludeIgnored) {
            result = result.concat(this.getPreferenceSearchExcludes());
        }
        return result;
    }
    setDefaultIncludeValue() {
        const searchIncludes = this.searchPreferences["search.include" /* SearchSettingId.Include */] || {};
        this.includeValue = Object.keys(searchIncludes)
            .reduce((includes, key) => {
            if (searchIncludes[key]) {
                includes.push(key);
            }
            return includes;
        }, [])
            .join(',');
        // 如有 include 填充，则显示搜索条件
        if (this.includeValue) {
            this.updateUIState({ isDetailOpen: true });
        }
    }
    mergeSameUriResult(data, searchResultMap, docSearchedList, total) {
        const theTotal = total || { fileNum: 0, resultNum: 0 };
        data.forEach((result) => {
            const oldData = searchResultMap.get(result.fileUri);
            if (docSearchedList.indexOf(result.fileUri) > -1) {
                // 通过docModel搜索过的文件不再搜索
                return;
            }
            if (oldData) {
                oldData.push(result);
                searchResultMap.set(result.fileUri, oldData);
                theTotal.resultNum++;
            }
            else {
                searchResultMap.set(result.fileUri, [result]);
                theTotal.fileNum++;
                theTotal.resultNum++;
            }
        });
        return {
            searchResultMap,
            total: theTotal,
        };
    }
    searchFromDocModel(searchOptions, docModel, searchValue, rootDirs, codeEditor) {
        let matcherList = [];
        const uriString = docModel.uri.toString();
        const result = [];
        const searchedList = [];
        if (!rootDirs.some((root) => uriString.startsWith(root))) {
            return {
                result,
                searchedList,
            };
        }
        if (searchOptions.include && searchOptions.include.length > 0) {
            // include 设置时，若匹配不到则返回空
            searchOptions.include.forEach((str) => {
                matcherList.push((0, ide_core_browser_1.parseGlob)((0, common_1.anchorGlob)(str)));
            });
            const isInclude = matcherList.some((matcher) => matcher(uriString));
            matcherList = [];
            if (!isInclude) {
                return {
                    result,
                    searchedList,
                };
            }
        }
        if (searchOptions.exclude && searchOptions.exclude.length > 0) {
            // exclude 设置时，若匹配到则返回空
            searchOptions.exclude.forEach((str) => {
                matcherList.push((0, ide_core_browser_1.parseGlob)((0, common_1.anchorGlob)(str)));
            });
            const isExclude = matcherList.some((matcher) => matcher(uriString));
            matcherList = [];
            if (isExclude) {
                return {
                    result,
                    searchedList,
                };
            }
        }
        const textModel = docModel.getMonacoModel();
        searchedList.push(docModel.uri.toString());
        const findResults = textModel.findMatches(searchValue, true, !!searchOptions.useRegExp, !!searchOptions.matchCase, searchOptions.matchWholeWord ? '`~!@#$%^&*()-=+[{]}\\|;:\'",.<>/? \n' : null, false);
        findResults.forEach((find, index) => {
            if (index === 0 && codeEditor) {
                // 给打开文件添加选中状态
                this.setEditorSelections(codeEditor, find.range);
            }
            result.push((0, common_1.cutShortSearchResult)({
                fileUri: docModel.uri.toString(),
                line: find.range.startLineNumber,
                matchStart: find.range.startColumn,
                matchLength: find.range.endColumn - find.range.startColumn,
                lineText: textModel.getLineContent(find.range.startLineNumber),
            }));
        });
        return {
            result,
            searchedList,
        };
    }
    async searchAllFromDocModel(options) {
        const searchValue = options.searchValue;
        const searchOptions = options.searchOptions;
        const documentModelManager = options.documentModelManager;
        const rootDirs = options.rootDirs;
        let result = [];
        let searchedList = [];
        const docModels = documentModelManager.getAllModels();
        const group = this.workbenchEditorService.currentEditorGroup;
        const filterFileWithGlobRelativePath = new common_1.FilterFileWithGlobRelativePath(rootDirs, searchOptions.include || []);
        await Promise.all(docModels.map(async (docModel) => {
            const uriString = docModel.uri.toString();
            // 只搜索file协议内容
            if (docModel.uri.scheme !== ide_core_browser_1.Schemes.file) {
                return;
            }
            const resource = await this.resourceService.getResource(docModel.uri);
            if (!resource || resource.deleted) {
                return;
            }
            if (!filterFileWithGlobRelativePath.test(uriString)) {
                return;
            }
            const data = this.searchFromDocModel(searchOptions, docModel, searchValue, rootDirs, group.codeEditor);
            result = result.concat(data.result);
            searchedList = searchedList.concat(data.searchedList);
        }));
        return {
            result,
            searchedList,
        };
    }
    fireTitleChange() {
        this.onDidTitleChangeEmitter.fire();
    }
    refresh() {
        this.search();
    }
    dispose() {
        var _a;
        super.dispose();
        (_a = this.eventBusDisposer) === null || _a === void 0 ? void 0 : _a.dispose();
        this.blur();
    }
};
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_common_1.IEventBus),
    tslib_1.__metadata("design:type", Object)
], ContentSearchClientService.prototype, "eventBus", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(search_preferences_1.SearchPreferences),
    tslib_1.__metadata("design:type", Object)
], ContentSearchClientService.prototype, "searchPreferences", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(core_preferences_1.CorePreferences),
    tslib_1.__metadata("design:type", Object)
], ContentSearchClientService.prototype, "corePreferences", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(common_1.ContentSearchServerPath),
    tslib_1.__metadata("design:type", Object)
], ContentSearchClientService.prototype, "contentSearchServer", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_workspace_1.IWorkspaceService),
    tslib_1.__metadata("design:type", Object)
], ContentSearchClientService.prototype, "workspaceService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_browser_1.RecentStorage),
    tslib_1.__metadata("design:type", ide_core_browser_1.RecentStorage)
], ContentSearchClientService.prototype, "recentStorage", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(browser_1.IEditorDocumentModelService),
    tslib_1.__metadata("design:type", Object)
], ContentSearchClientService.prototype, "documentModelManager", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_browser_1.CommandService),
    tslib_1.__metadata("design:type", Object)
], ContentSearchClientService.prototype, "commandService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(storage_service_1.GlobalBrowserStorageService),
    tslib_1.__metadata("design:type", storage_service_1.GlobalBrowserStorageService)
], ContentSearchClientService.prototype, "browserStorageService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_overlay_1.IDialogService),
    tslib_1.__metadata("design:type", Object)
], ContentSearchClientService.prototype, "dialogService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_overlay_1.IMessageService),
    tslib_1.__metadata("design:type", Object)
], ContentSearchClientService.prototype, "messageService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_workspace_edit_1.IWorkspaceEditService),
    tslib_1.__metadata("design:type", Object)
], ContentSearchClientService.prototype, "workspaceEditService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_common_1.IReporterService),
    tslib_1.__metadata("design:type", Object)
], ContentSearchClientService.prototype, "reporterService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_browser_1.PreferenceService),
    tslib_1.__metadata("design:type", Object)
], ContentSearchClientService.prototype, "preferenceService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_editor_1.WorkbenchEditorService),
    tslib_1.__metadata("design:type", ide_editor_1.WorkbenchEditorService)
], ContentSearchClientService.prototype, "workbenchEditorService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(),
    tslib_1.__metadata("design:type", browser_1.ResourceService)
], ContentSearchClientService.prototype, "resourceService", void 0);
ContentSearchClientService = tslib_1.__decorate([
    (0, di_1.Injectable)(),
    tslib_1.__metadata("design:paramtypes", [])
], ContentSearchClientService);
exports.ContentSearchClientService = ContentSearchClientService;
//# sourceMappingURL=search.service.js.map